#
#  Cours Introduction to programming: Application of R
#  Yeganeh Forouheshfar
#
#  sujet: Faire des satistques descriptives et les graphiques simple
#------------------------------




# LOAD DATASETS PACKAGES ###################################

library(datasets)  # Load/unload base packages manually

# Installs pacman ("package manager") if needed
if (!require("pacman")) install.packages("pacman")

# Use pacman to load add-on packages as desired
pacman::p_load(pacman, psych, pastecs) 

# (pastecs) is to use the function stat.desc()

# PSYCH PACKAGE for the "describe" function later on ##########

# Get info & help on package

p_help(psych, web = F)  # Opens help in R Viewer

?`psych-package`
help("psych-package")

###########

?iris
head(iris)
data("iris") #iris will become an object in the environment


# SUMMARY() ################################################


summary(iris)               # Entire data frame
summary(iris$Species)       # Categorical variable
summary(iris$Sepal.Length)  # Quantitative variable


describe(iris$Sepal.Length)  # One quantitative variable
describe(iris)               # Entire data frame


# in order to call data names easier###########
attach(iris)
summary(Species) # You do not need to mention the $ sign for calling variables
#

median(Petal.Length)


# PLOT DATA WITH PLOT() ####################################

?plot  # Help for plot()

plot(iris$Species)  # Categorical variable
plot(iris$Petal.Length)  # Quantitative variable



barplot (table(Species)) # another option for a bar plot

# La fonction pie sera utilisée pour les variables qualitatives nominales (diagramme en secteurs circulaires)
pie (table(Species), main="Distribution of Species")




plot(iris$Species, iris$Petal.Width)  # Cat x quant
boxplot(iris$Petal.Width ~ iris$Species)

plot(iris$Petal.Length, iris$Petal.Width)  # Quant pair X,Y
plot(iris$Petal.Length ~ iris$Petal.Width)  # Quant pair Y,X

plot(iris)  # Entire data frame


# Plot with options
plot(iris$Petal.Length, iris$Petal.Width,
     col = "#75197F",  # Hex code for datalab.cc red
     pch = 6,         # Use solid circles for points
     main = "Iris: Petal Length vs. Petal Width",
     xlab = "Petal Length",
     ylab = "Petal Width")

# PLOT FORMULAS WITH PLOT() ################################

plot(sin, 0, 2*pi)
plot(exp, 1, 4) # exponential function
plot(dnorm, -3, +3) # normal  distribution / distribution function

# Formula plot with options
plot(dnorm, -3, +3,
     col = "#cc0000",
     lwd = 5,  #line widths
     main = "Standard Normal Distribution",
     xlab = "z-scores",
     ylab = "Density")


# BASIC HISTOGRAMS #########################################

hist(iris$Sepal.Length)
hist(iris$Sepal.Width)
hist(iris$Petal.Length)
hist(iris$Petal.Width)

# HISTOGRAM BY GROUP #######################################

# Put graphs in 3 rows and 1 column
par(mfrow = c(3, 1))

# Histograms for each species using options
hist(iris$Petal.Width [iris$Species == "setosa"],
     xlim = c(0, 3),
     breaks = 5,
     main = "Petal Width for Setosa",
     xlab = "",
     col = "red")

hist(iris$Petal.Width [iris$Species == "versicolor"],
     xlim = c(0, 3),
     breaks = 9,
     main = "Petal Width for Versicolor",
     xlab = "",
     col = "purple")

hist(iris$Petal.Width [iris$Species == "virginica"],
     xlim = c(0, 3),
     breaks = 9,
     main = "Petal Width for Virginica",
     xlab = "",
     col = "blue")

# Restore graphic parameter
par(mfrow=c(1, 1))


# Change the DATA set for an example of bar chart ####################



# LOAD DATA ################################################

?mtcars
head(mtcars)

# DESCRIPTIVE STATISTICS ##################################
summary(mtcars)
describe(mtcars)
stat.desc(mtcars)

describeBy(mtcars,mtcars$cyl) # having descriptive statistics by a category or another variable
plot(mtcars$cyl, mtcars$mpg)


# PLOTS ####################################################

# Good to first check univariate distributions
hist(mtcars$wt)
hist(mtcars$mpg)
hist(mtcars$cyl)


# Basic X-Y plot for two quantitative variables
plot(mtcars$wt, mtcars$mpg)

# Add some options
plot(mtcars$wt, mtcars$mpg,
     pch = 19,         # Solid circle
     cex = 1.5,        # Make 150% size
     col = "red",  # or you can put the color Hex code: "#cc0000" for red
     main = "MPG as a Function of Weight of Cars",
     xlab = "Weight (in 1000 pounds)",
     ylab = "MPG")


barplot(mtcars$cyl)             # Doesn't work

# Need a table with frequencies for each category
(cylinders <- table(mtcars$cyl)) # Create table
barplot(cylinders)              # Bar chart
plot(cylinders)                 # Default X-Y plot (lines)




# CLEAN UP #################################################


# Clear plots
dev.off()  # But only if there IS a plot


# Clear environment
rm(list = ls()) 

# Clear packages
p_unload(all)  # Remove all add-ons

# Clear console
cat("\014")  # ctrl+L

