#
#  Cours Introduction to programming:Application of R
#  Yeganeh Forouheshfar
#
#  sujet: Faire une regression linéaire
#------------------------------


# INSTALL AND LOAD PACKAGES ################################

library(datasets)  # Load base packages manually

# Installs pacman ("package manager") if needed
if (!require("pacman")) install.packages("pacman")

# Use pacman to load add-on packages as desired
pacman::p_load(pacman, caret, lars, tidyverse, jtools, huxtable, 
               officer, flextable, texreg, AER)

#-------------------------------------------------------------------
### before starting with regressions, let's see:
#### How to change a variable name? 
#### Example changing the name of the variable CONT to contacts in USJudgeRatings dataset

Mydata1 <- USJudgeRatings %>%  
  rename(contacts = CONT)

#      %>% is equivalent to say "and then"

# we can also select a number of variables within a dataset
Mydata2 <- USJudgeRatings %>%  
 select(CONT,INTG,RTEN) %>% 
  rename(contacts = CONT)%>% 
  rename(worthy= RTEN)



# LOAD DATA ################################################

?USJudgeRatings
head(USJudgeRatings)

summary(USJudgeRatings)

# You can specify variables individually

reg1 <- lm(USJudgeRatings$RTEN ~ USJudgeRatings$CONT) 

reg1 <- lm(RTEN ~ CONT, data = USJudgeRatings) 


summary(reg1)
summ(reg1) # from jtools package 

# visualization of the regression line
plot(RTEN ~ CONT, data = USJudgeRatings)
abline(reg1)



summary(reg2 <- lm(RTEN ~ CONT + INTG + DMNR + DILG + CFMG +
             DECI + PREP + FAMI + ORAL + WRIT + PHYS,
           data = USJudgeRatings))

summ(reg2)


?export_summs

export_summs(reg2)
# In order to export your regression tables in a clean format
export_summs(reg1, reg2) # to have publishable Table output
export_summs(reg1, reg2, scale = TRUE,
             error_format ="[{conf.low}, {conf.high}]") #play with the options


# export to doc or pdf or Excel or HTML
export_summs(reg1, reg2, to.file = "docx", file.name = "test.docx")
export_summs(reg1, reg2, to.file = "xlsx", file.name = "test2.xlsx")
#  PDF ("PDF"), HTML ("HTML"), or Excel format ("xlsx")




data <- USJudgeRatings
# Or define variable groups
x <- as.matrix(data[, -12]) 
y <- data[,11]

# REGRESSION WITH SIMULTANEOUS ENTRY #######################

# Using variable groups
reg3 <- lm(y ~ x)



# Results
reg3# Coefficients only
summary(reg3)  # Inferential tests

# MORE SUMMARIES ###########################################

anova(reg3)            # Coefficients w/inferential tests
coef(reg3)             # Coefficients (same as reg1)
confint(reg3)          # CI for coefficients
resid(reg3)            # Residuals case-by-case
hist(residuals(reg3))  # Histogram of residuals







# CLEAN UP #################################################

# Clear environment
rm(list = ls()) 

# Clear packages
p_unload(all)  # Remove all add-ons

# Clear console
cat("\014")  # ctrl+L
