#
#  Cours Introduction à l'économétrie: Application R
#  Yeganeh Forouheshfar
#
#  sujet: ggplot
#------------------------------


# Use pacman to load add-on packages as desired
pacman::p_load(pacman, caret, lars, tidyverse, rio, psych, GGally,arm, AER)



data("Journals", package = "AER")
#Data set from Stock & Watson (2007), originally collected by T. Bergstrom, on subscriptions to 180 economics journals at US libraries, for the year 2000

# Goal: Relationship between the number of subscriptions and the price per citation for economics journals.





journals <- Journals[, c("subs", "price")]

journals$citeprice <- Journals$price/Journals$citations # creation of a new variable

summary(journals)

attach(journals)

plot(subs,citeprice, data=Journals)

plot(subs ~ citeprice, data = journals) # a nonlinear relationship
plot(log(subs) ~ log(citeprice), data = journals) # Using log-linearisation


?rug
rug(log(citeprice))
rug(log(subs), side = 2)



plot(log(subs) ~ log(citeprice), data = Journals, pch = 20,
     col = "blue", ylim = c(0, 8), xlim = c(-7, 4),
     main = "Library subscriptions")  #changing the graphical parameters



reg_jour <- lm(log(subs) ~ log(citeprice), data = journals)


?abline  
abline(reg_jour) # Add straight line 

summary(reg_jour)


plot(reg_jour) # plotting a regression!

plot(reg_jour, which = 1) # Plots are also accessible individually,


##  using ggplot for sophisticated graphs
?ggplot


Journals %>%
  ggplot(aes(x=citations, y=price)) + geom_point()

Journals %>%
  ggplot(aes(x=log(subs),
             y=log(price)-log(citations),
             col=society,
             size=pages)) + geom_point() # A figure



Journals %>%
  filter(foundingyear>=1970)%>%
  ggplot(aes(x=log(subs),
             y=log(price)-log(citations),
             col=field, size=pages)) + geom_point() 
# similar figure as before with a filter for date





####Exporting graphics

pdf("~/Desktop/testfile.pdf", height = 5, width = 6)
plot(log(subs) ~ log(citeprice), data = journals) 
dev.off()

# or you can simply use the export button but the same commands will be run



#### bonus: to have an overview of the charts in R
demo("graphics")



# CLEAN UP #################################################

# Clear plots
dev.off()  # But only if there IS a plot

# Clear environment
rm(list = ls()) 

# Clear packages
p_unload(all)  # Remove all add-ons

# Clear console
cat("\014")  # ctrl+L
