#
#  Cours Introduction to programming: Application of R
#  Yeganeh Forouheshfar
#
#  sujet: Probit and Logit Models in R
#------------------------------


# inspired from:
# Copyright 2013 by Ani Katchova
# check: https://www.youtube.com/watch?time_continue=2&v=A9P888Lxde8&feature=emb_logo
#

# Use pacman to load add-on packages as desired
pacman::p_load(pacman, caret, lars, tidyverse, rio, psych, 
               GGally,arm,dplyr, huxtable, officer, flextable,
               jtools, plyr, margins)



#-- import the file entitled "infidelité_probit.xlsx"
infidelite <- import(file.choose())



attach(infidelite)

head(infidelite)




# Define variables
Y <- cbind(Affaire)
X <- cbind(Z1, Z2, Z3, Z4, Z5, Z6, Z7, Z8)



# Descriptive statistics
summary(Y)
summary(X)

table(Y)
#-- to calculate the percentage of infidel people (25%)
table(Y)/sum(table(Y))

# Regression coefficients
olsreg <- lm(Y ~ X)
summary(olsreg)
#--- the linear model is not a very good option as the dependant variable is a dummy, logit and probit are better options


# Logit model coefficients
logit<- glm(Y ~ X, family=binomial (link = "logit"))
summary(logit) 
#-- The coefficient values cannot be interpreted, you can talk about more likely or less likely (ex. people married for lobger time are more likely to have an affaire) 

# Logit model odds ratios: odds ratio is a statistic that quantifies the strength of the association between two events
exp(logit$coefficients)



# Probit model coefficients
probit<- glm(Y ~ X, family=binomial (link="probit"))
summary(probit)




###### marginal effects ###### to calculate the magnitude of effects


# Regression marginal effects
coef(olsreg)
#-- in a linear model coefficients are the marginal effects!



# Logit model average marginal effects  (Marginal effects can be calculated for each observation point, common calculations are to calculate the marginal effects at the mean or better--> calculate the average marginal effects)
LogitScalar <- mean(dlogis(predict(logit, type = "link")))
LogitScalar * coef(logit)




# Probit model average marginal effects
ProbitScalar <- mean(dnorm(predict(probit, type = "link")))
ProbitScalar * coef(probit)




##### Predicted Probabilities ######
# in this section we see whether the models predict probabilities higher than 0.5 for the infidel cases(Y=1) and probabilities less than 0.5 for the cases where Y=0



# Regression predicted probabilities
polsreg<- predict(olsreg)
summary(polsreg)

# Logit model predicted probabilities
plogit<- predict(logit, type="response")
summary(plogit)

# Probit model predicted probabilities
pprobit<- predict(probit, type="response")
summary(pprobit)


# Percent correctly predicted values
table(true = Y, pred = round(fitted(probit)))
table(true = Y, pred = round(fitted(logit))) 
#--function fitted caculates the predicted /fitted values and the function round will round thoses higher that 0.5 to 1 and lower than 0.5 to 0
#-- This is a way to see if our model predicts correctly Y 


# We do not have R-squared for alogit or probit model but we can build a similar concept:
# McFadden's Pseudo R-squared
probit0<-update(probit, formula= Y ~ 1)
McFadden<- 1-as.vector(logLik(probit)/logLik(probit0))
McFadden



# CLEAN UP #################################################

# Clear environment
rm(list = ls()) 

# Clear packages
p_unload(all)  # Remove all add-ons

# Clear console
cat("\014")  # ctrl+L

